Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Conditioned ¶
type Conditioned interface {
SetConditions(...metav1.Condition)
GetCondition(string) *metav1.Condition
}
A Conditioned may have conditions set or retrieved. Conditions typically indicate the status of both a resource and its reconciliation process.
type ConditionedAgentObj ¶ added in v0.3.0
type ConditionedAgentObj interface {
client.Object
ConditionedWithType
}
A ConditionedAgentObj is for kubernetes resources where multiple agents can set and update conditions within AgentStatus.
type ConditionedObj ¶
type ConditionedObj interface {
client.Object
Conditioned
}
A ConditionedObj is for kubernetes resource with conditions.
type ConditionedWithType ¶ added in v0.3.0
type ConditionedWithType interface {
SetConditionsWithType(fleetv1alpha1.AgentType, ...metav1.Condition)
GetConditionWithType(fleetv1alpha1.AgentType, string) *metav1.Condition
}
A ConditionedWithType may have conditions set or retrieved based on agent type. Conditions typically indicate the status of both a resource and its reconciliation process.
Click to show internal directories.
Click to hide internal directories.